@@ -4,10 +4,11 @@ Para seguir a nomemclatura de nuvem, designado aqui como 'Region'
 """
 
 
+# pylint: disable=too-few-public-methods
 class SCRegion():
     REGIAO_PADRAO = 'default'
 
-    def __init__(self, id_no, nome_no, grupo, cluster, letra_id):
+    def __init__(self, id_no, nome_no, grupo, cluster, letra_id=None):
         self.id_no = id_no
         self.nome_no = nome_no
         self.grupo = grupo
